/*
 * ISiteDiscovery.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: elefth, Standlove
 *          Pops, TCSDEVELOPER
 */

using System.Collections;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// Defines the contract for a data source for the site.
    /// </summary>
    ///
    /// <remarks>
    /// <para>
    /// Implementations of this interface should create and return a site map
    /// (in an <see cref="IDictionary"/> implementation) consisting of
    /// <see cref="INodeMatcher"/> nodes that describe the site map.
    /// The returned IDictionary should have each unique <see cref="INodeMatcher"/> listed
    /// as the key and an <see cref="IList"/> of <see cref="INodeMatcher"/> nodes that
    /// describe the children of that key.
    /// </para>
    /// <para>
    /// <b>Thread Safety:</b> Implementations of this interface should be thread safe.
    /// </para>
    /// </remarks>
    public interface ISiteDiscovery
    {
        /// <summary>
        /// Returns an <see cref="IDictionary"/> implementation of <see cref="INodeMatcher"/> keys
        /// with an <see cref="IList"/> of <see cref="INodeMatcher"/> elements as the value.
        /// </summary>
        ///
        /// <remarks>
        /// The key <see cref="INodeMatcher"/> represents the parent and the value (the list)
        /// represents the child values. The value can be null or an empty list to represent
        /// no child elements (ie. it's a leaf node).
        /// </remarks>
        ///
        /// <returns>
        /// A non-null <see cref="IDictionary"/> implementation of parent <see cref="INodeMatcher"/>
        /// to a list of <see cref="INodeMatcher"/> children.
        /// </returns>
        ///
        /// <exception cref="BreadCrumbException">
        /// Any error occurs retrieving the site map.
        /// </exception>
        IDictionary GetSiteMap();
    }
}


