/*
 * Demo.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;
using System.Collections;
using NUnit.Framework;
using NUnit.Extensions.Asp;
using NUnit.Extensions.Asp.AspTester;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.Tests
{
    /// <summary>
    /// Demonstrates component functionality using the Demo directory on the server.
    /// </summary>
    [TestFixture]
    public class Demo : WebFormTestCase
    {
        /// <summary>
        /// The path of the aspx demo files.
        /// </summary>
        private const string DemoPath = TestCommon.AppPath + "/Demo";

        /// <summary>
        /// The url of the aspx used to demo.
        /// </summary>
        private const string TestUrl = TestCommon.IisServer + DemoPath;

        /// <summary>
        /// Represents the bcc control. Initialized in SetUp.
        /// </summary>
        private LabelTester bcc;

        /// <summary>
        /// Initializes the control testers.
        /// </summary>
        protected override void SetUp()
        {
            bcc = new LabelTester("bcc", CurrentWebForm);
        }

        /// <summary>
        /// Tests Browsing around the demo site.
        /// The bread crumb control is updated as we visit different pages.
        /// </summary>
        [Test]
        public void TestBrowse()
        {
            // go to Main page
            Browser.GetPage(TestUrl + "/Main.aspx");

            string mainBcc = "<a class=\"ConfigRNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigRNS'\" href=\"/BreadCrumbTrailWeb/Demo/Main.aspx\">"
                + "Main Page</a>";
            AssertEquals("Main bcc not rendered incorrectly", mainBcc, bcc.Text);

            // goto Forum page
            Browser.GetPage(TestUrl + "/Forums/Forums.aspx");

            string forumsBcc = mainBcc +
                "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigCNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigCNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Forums.aspx\">"
                + "Forums Page</a>";
            AssertEquals("Forums bcc rendered incorrectly", forumsBcc, bcc.Text);

            // goto Help page
            Browser.GetPage(TestUrl + "/Forums/Help.aspx");

            string helpBcc = mainBcc +
                "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Forums.aspx\">"
                + "Forums Page</a>"

                + "<span class=\"ConfigPSS\"> &gt; </span>"
                + "<a class=\"ConfigCNS\" onmouseover=\"this.className='ConfigMOS'\" "
                + "onmouseout=\"this.className='ConfigCNS'\" href=\"/BreadCrumbTrailWeb/Demo/Forums/Help.aspx\">"
                + "Help Page</a>";
            AssertEquals("Help bcc rendered incorrectly", helpBcc, bcc.Text);

            // go back to Main page
            Browser.GetPage(TestUrl + "/Main.aspx");
            AssertEquals("Go back Main bcc", mainBcc, bcc.Text);
        }
    }
}
