/*
 * MyNodeMatcher.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery.Tests
{
    /// <summary>
    /// A concrete class derived from <see cref="AbstractNodeMatcher"/>
    /// used to test <see cref="AbstractNodeMatcher"/>.
    /// </summary>
    ///
    /// <remarks>
    /// This class provides empty implementation of <see cref="Matches"/>
    /// that always return true.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    [Serializable]
    public class MyNodeMatcher : AbstractNodeMatcher
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MyNodeMatcher"/> class
        /// with the specified title and url.
        /// </summary>
        ///
        /// <param name="title">
        /// A non-null, non-empty (trimmed) title to use.
        /// </param>
        /// <param name="url">
        /// A non-null, non-empty (trimmed) url to use.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// Any of the argument is a null reference.
        /// </exception>
        /// <exception cref="ArgumentException">
        /// Any of the argument is an empty trimmed string.
        /// </exception>
        public MyNodeMatcher(string title, string url)
            : base(title, url)
        {
        }

        /// <summary>
        /// Always returns true.
        /// </summary>
        ///
        /// <param name="node">
        /// N/A.
        /// </param>
        ///
        /// <returns>
        /// Always true.
        /// </returns>
        public override bool Matches(BreadCrumbNode node)
        {
            return true;
        }
    }
}
