/*
 * TestBreadCrumbTrailControlAsp.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;
using System.Collections;
using NUnit.Framework;
using NUnit.Extensions.Asp;
using NUnit.Extensions.Asp.AspTester;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.Tests
{
    /// <summary>
    /// Unit tests for the <see cref="BreadCrumbTrailControl"/> class
    /// with the help of NUnitAsp and TestBreadCrumbTrailControlBind.aspx.
    /// </summary>
    ///
    /// <remarks>
    /// This test the DataBind with various possible data type.
    /// </remarks>
    [TestFixture]
    public class TestBreadCrumbTrailControlAsp : WebFormTestCase
    {
        /// <summary>
        /// The path of the aspx file.
        /// </summary>
        private const string TestPath = TestCommon.AppPath + "/TestBreadCrumbTrailControlBind.aspx";

        /// <summary>
        /// The url of the aspx used to test BreadCrumbTrailControl.
        /// </summary>
        private const string TestUrl = TestCommon.IisServer + TestPath;

        /// <summary>
        /// Represents the source text box. Initialized in SetUp.
        /// </summary>
        private TextBoxTester source;

        /// <summary>
        /// Represents the bcc control. Initialized in SetUp.
        /// </summary>
        private LabelTester bcc;

        /// <summary>
        /// Represents the btnBind button. Initialized in SetUp.
        /// </summary>
        private ButtonTester btnBind;

        /// <summary>
        /// The expected render result. Substitute {0} with test number.
        /// </summary>
        private const string ExpectedRender =
            "<a class=\"ConfigRNS\" onmouseover=\"this.className='ConfigMOS'\" "
            + "onmouseout=\"this.className='ConfigRNS'\" href=\"http://www.xyz.com\">"
            + "Main-{0}</a><span class=\"ConfigPSS\"> &gt; </span>"

            + "<a class=\"ConfigCNS\" onmouseover=\"this.className='ConfigMOS'\" "
            + "onmouseout=\"this.className='ConfigCNS'\" href=\"http://www.xyz.com/forums\">"
            + "Forums-{0}</a>";


        /// <summary>
        /// Initializes the control testers.
        /// </summary>
        protected override void SetUp()
        {
            source = new TextBoxTester("source", CurrentWebForm);
            bcc = new LabelTester("bcc", CurrentWebForm);
            btnBind = new ButtonTester("btnBind", CurrentWebForm);

            Browser.GetPage(TestUrl);
        }

        /// <summary>
        /// Tests DataBind with BreadCrumbNode[] source.
        /// </summary>
        [Test]
        public void TestDataBindArray()
        {
            source.Text = "1";
            btnBind.Click();

            AssertEquals("Array not rendered incorrectly",
                string.Format(ExpectedRender, "1"), bcc.Text);
        }

        /// <summary>
        /// Tests DataBind with IList[] source.
        /// </summary>
        [Test]
        public void TestDataBindIList()
        {
            source.Text = "2";
            btnBind.Click();

            AssertEquals("Array not rendered incorrectly",
                string.Format(ExpectedRender, "2"), bcc.Text);
        }

        /// <summary>
        /// Tests DataBind with DataTable source.
        /// </summary>
        [Test]
        public void TestDataBindDataTable()
        {
            source.Text = "3";
            btnBind.Click();

            AssertEquals("Array not rendered incorrectly",
                string.Format(ExpectedRender, "3"), bcc.Text);
        }

        /// <summary>
        /// Tests DataBind with DataSet source.
        /// </summary>
        [Test]
        public void TestDataBindDataSet()
        {
            source.Text = "4";
            btnBind.Click();

            AssertEquals("Array not rendered incorrectly",
                string.Format(ExpectedRender, "4"), bcc.Text);
        }
    }
}
